@@ -146,7 +146,7 @@ in_disaggr_notctb <- function(object,type) {
   
 }
 
-in_disaggr_ctb <- function(object,type) UseMethod("in_disaggr_ctb")
+in_disaggr_ctb <- function(object) UseMethod("in_disaggr_ctb")
 
 in_disaggr_ctb.threeRuleSmooth <- function(object) {
   benchmark <- na.omit(as.ts(object))
